==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WilliamsPercentRIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { WilliamsPercentRIndicatorDescription } from "./WilliamsPercentRIndicatorDescription";
/**
 * @hidden
 */
export let WilliamsPercentRIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WilliamsPercentRIndicatorDescriptionMetadata.a == null) {
                WilliamsPercentRIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WilliamsPercentRIndicatorDescriptionMetadata.c(WilliamsPercentRIndicatorDescriptionMetadata.a);
            }
            if (a.k(WilliamsPercentRIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            WilliamsPercentRIndicatorDescriptionMetadata.b(a);
            a.ad("WilliamsPercentRIndicator", () => new WilliamsPercentRIndicatorDescription());
            a.ac("WilliamsPercentRIndicator", WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
    }
    WilliamsPercentRIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(WilliamsPercentRIndicatorDescriptionMetadata, 'WilliamsPercentRIndicatorDescriptionMetadata');
    WilliamsPercentRIndicatorDescriptionMetadata.a = null;
    return WilliamsPercentRIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WilliamsPercentRIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { WilliamsPercentRIndicatorDescription } from "./WilliamsPercentRIndicatorDescription";
/**
 * @hidden
 */
export let WilliamsPercentRIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (WilliamsPercentRIndicatorDescriptionMetadata.a == null) {
                WilliamsPercentRIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WilliamsPercentRIndicatorDescriptionMetadata.c(WilliamsPercentRIndicatorDescriptionMetadata.a);
            }
            if (a.k(WilliamsPercentRIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            WilliamsPercentRIndicatorDescriptionMetadata.b(a);
            a.ae("WilliamsPercentRIndicator", () => new WilliamsPercentRIndicatorDescription());
            a.ad("WilliamsPercentRIndicator", WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
    }
    WilliamsPercentRIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(WilliamsPercentRIndicatorDescriptionMetadata, 'WilliamsPercentRIndicatorDescriptionMetadata');
    WilliamsPercentRIndicatorDescriptionMetadata.a = null;
    return WilliamsPercentRIndicatorDescriptionMetadata;
})();
